import React from 'react'
import styled from 'styled-components'
import { reduxForm } from 'redux-form'
import { withJournal } from 'xpub-journal'
import { compose, withProps, withHandlers, withState } from 'recompose'
import { onSubmitUser as onSubmit } from '../utils'

import AccountDetailsCard from './AccountDetailsCard'
import AccountDetailsEdit from './AccountDetailsEdit'

const AccountDetails = ({
  user,
  isEdit,
  setEditMode,
  journal,
  handleSubmit,
}) => (
  <Root>
    {isEdit ? (
      <form onSubmit={handleSubmit}>
        <AccountDetailsEdit
          journal={journal}
          setEditMode={setEditMode}
          user={user}
        />
      </form>
    ) : (
      <AccountDetailsCard
        journal={journal}
        setEditMode={setEditMode}
        user={user}
      />
    )}
  </Root>
)

export default compose(
  withJournal,
  withState('isEdit', 'setEdit', false),
  withHandlers({
    setEditMode: ({ setEdit }) => value => setEdit(value),
  }),
  withProps(({ user }) => ({ initialValues: user })),
  reduxForm({
    form: 'userManagement',
    onSubmit,
  }),
)(AccountDetails)

// #region styles
const Root = styled.div`
  display: flex;
  flex-direction: column;
  max-width: 30em;
`
// #endregion
